///*
//  Communicate with BME280s with different I2C addresses
//  Nathan Seidle @ SparkFun Electronics
//  March 23, 2015
//
//  Feel like supporting our work? Buy a board from SparkFun!
//  https://www.sparkfun.com/products/14348 - Qwiic Combo Board
//  https://www.sparkfun.com/products/13676 - BME280 Breakout Board
//
//  This example shows how to connect two sensors on the same I2C bus.
//
//  The BME280 has two I2C addresses: 0x77 (jumper open) or 0x76 (jumper closed)
//
//  Hardware connections:
//  BME280 -> Arduino
//  GND -> GND
//  3.3 -> 3.3
//  SDA -> A4
//  SCL -> A5
//*/
//
//#include <Wire.h>
//
//#include "SparkFunBME280.h"
//BME280 mySensorA; //Uses default I2C address 0x77
//BME280 mySensorB; //Uses I2C address 0x76 (jumper closed)
//
//void setup()
//{
//  Serial.begin(115200);
//  Serial.println("Example showing alternate I2C addresses");
//
//  Wire.begin();
//
//  mySensorA.setI2CAddress(0x76); //The default for the SparkFun Environmental Combo board is 0x77 (jumper open).
//  //If you close the jumper it is 0x76
//  //The I2C address must be set before .begin() otherwise the cal values will fail to load.
//
//  if(mySensorA.beginI2C() == false){
//    Serial.println("Sensor A connect failed");
//    while(1); //Stop the code if sensor A is not working
//  }
//
//}
//
//void loop()
//{
//  
// Serial.print(" TempA: ");
//Serial.print(mySensorA.readTempC(), 2);
//
//  Serial.println();
//
//  delay(1000);
//}


//
//#include <Wire.h>
//#include <LiquidCrystal_I2C.h>
//#include "SparkFunBME280.h"
//
//LiquidCrystal_I2C lcd(0x27, 16, 2);
//
//BME280 mySensorA;
//
//void setup() {
//  lcd.init();
//  lcd.backlight();
//
//  Wire.begin();
//
//  mySensorA.setI2CAddress(0x76);
//
//  if (!mySensorA.beginI2C()) {
//    Serial.println("Sensor A connect failed");
//    //while (1);
//  }
//}
//
//void loop() {
//  lcd.setCursor(0, 0);
//  lcd.print("Room temp:");
//  lcd.print(mySensorA.readTempC(), 2);
//  lcd.print("C");
//  int potValue = analogRead(A0);  // Read the value of the potentiometer
//int wantedTemp = map(potValue, 0, 1023, 0, 50);  // Map the potentiometer value to a temperature range of 0-50C
//lcd.setCursor(0, 1);  // Set the cursor to the second row of the screen
//lcd.print("Wanted temp:");  // Print a message on the second row
//lcd.print(wantedTemp);  // Print the updated temperature value
//lcd.print("C");  // Print the temperature unit
//
//
//  delay(1000);
//
//  lcd.clear();
//}

//#include <Wire.h>
//#include <LiquidCrystal_I2C.h>
//#include "SparkFunBME280.h"
//
//LiquidCrystal_I2C lcd(0x27, 16, 2);
//
//BME280 mySensorA;
//
//int potPin = A0;    // Potentiometer connected to A0
//int fanPin = 8;     // Fan relay connected to pin 8
//int heatPin = 7;     // Red LED connected to pin 7
//const int blueBtnPin = 6;  // Blue button connected to pin 7
//const int redBtnPin = 5;   // Red button connected to pin 8
//int brightness = 255;      // Initial LCD brightness
//int wantedTemp = 25;       // Initial target temperature
//
//void setup() {
//  lcd.init();
//  lcd.backlight();
//
//  Wire.begin();
//
//  mySensorA.setI2CAddress(0x76);
//
//  if (!mySensorA.beginI2C()) {
//    Serial.println("Sensor A connect failed");
//   // while (1);
//  }
//
//  pinMode(fanPin, OUTPUT);
//  pinMode(heatPin, OUTPUT);
//  pinMode(blueBtnPin, INPUT_PULLUP);
//  pinMode(redBtnPin, INPUT_PULLUP);
//  digitalWrite(fanPin, HIGH); // turn off the fan relay initially
//}
//
//void loop() {
//  lcd.setCursor(0, 0);
//  lcd.print("Room temp:");
//  lcd.print(mySensorA.readTempC(), 2);
//  lcd.print("C");
//
// // int potValue = analogRead(potPin);  // Read the potentiometer value
// // int wantedTemp = map(potValue, 0, 1023, 20, 30);  // Map the potentiometer value to a temperature range of 20-30°C
//  lcd.setCursor(0, 1);
//  lcd.print("Wanted temp:");
//  lcd.print(wantedTemp);
//  lcd.print("C");
//
//  // Adjust target temperature using push buttons
//  if (digitalRead(blueBtnPin) == LOW) {
//    wantedTemp--;
//    delay(50);  // debounce
//  }
//  if (digitalRead(redBtnPin) == LOW) {
//    wantedTemp++;
//    delay(50);  // debounce
//  }
//
//  // Map the potentiometer value to a brightness range of 0-255
//  brightness = analogRead(potPin) / 4;
//
//  if (wantedTemp > mySensorA.readTempC()) {
//    digitalWrite(heatPin, HIGH);     // Turn on the heating element
//    digitalWrite(fanPin, LOW);     // Turn off the fan
//    lcd.setBacklight(brightness);    // Set LCD brightness
//  } else {
//    digitalWrite(heatPin, LOW);      // Turn off the heating element
//    digitalWrite(fanPin, HIGH);      // Turn off the fan
//    lcd.setBacklight(brightness);    // Set LCD brightness
//  }
//
//  delay(1000);
//
//  //lcd.clear();
//}

#include <Wire.h>
#include <LiquidCrystal_I2C.h>
#include "SparkFunBME280.h"

LiquidCrystal_I2C lcd(0x27, 16, 2);

BME280 mySensorA;

int fanPin = 8;     // Fan relay connected to pin 8
int heatPin = 7;     // Red LED connected to pin 7
const int blueBtnPin = 6;  // Blue button connected to pin 7
const int redBtnPin = 5;   // Red button connected to pin 8
int wantedTemp = 23;       // Initial target temperature

void setup() {
  lcd.init();
  lcd.backlight();

  Wire.begin();

  mySensorA.setI2CAddress(0x76);

  if (!mySensorA.beginI2C()) {
    Serial.println("Sensor A connect failed");
   // while (1);
  }

  pinMode(fanPin, OUTPUT);
  pinMode(heatPin, OUTPUT);
  pinMode(blueBtnPin, INPUT_PULLUP);
  pinMode(redBtnPin, INPUT_PULLUP);
  digitalWrite(fanPin, HIGH); // turn off the fan relay initially
}

void loop() {
  lcd.setCursor(0, 0);
  lcd.print("Room temp:");
  lcd.print(mySensorA.readTempC(), 2);
  lcd.print("C");


  lcd.setCursor(0, 1);
  lcd.print("Wanted temp:");
  lcd.print(wantedTemp);
  lcd.print("C");

  // Adjust target temperature using push buttons
  if (digitalRead(blueBtnPin) == LOW) {
    wantedTemp--;
    delay(100);  // debounce
  }
  if (digitalRead(redBtnPin) == LOW) {
    wantedTemp++;
    delay(100);  // debounce
  }


  if (wantedTemp > mySensorA.readTempC()) {
    digitalWrite(heatPin, HIGH);     // Turn on the heating element
    digitalWrite(fanPin, LOW);     // Turn off the fan
  } else {
    digitalWrite(heatPin, LOW);      // Turn off the heating element
    digitalWrite(fanPin, HIGH);      // Turn off the fan
  }

  delay(1000);

  //lcd.clear();
}
